var a = /*#__PURE__*/ React.createElement("abbr", {
    title: "\\d"
}, "\\d");
